@@ -1,5 +1,5 @@
 /* 
-   Copyright (C) 2009, 2010, 2011, 2012 German A. Arias <german@xelalug.org>
+   Copyright (C) 2009, 2010, 2011, 2012, 2013 German A. Arias
 
    This file is part of FísicaLab application
 
@@ -22,8 +22,8 @@
 
 @interface FLDynamics : FLSolverWithCells
 {
-  BOOL mensajeFr ;
-  NSArray *errores;
+  BOOL messageFr;
+  NSArray *errors;
 }
-- (void) crearEcuaciones: (NSMutableDictionary *)lista;
+- (void) makeEquationsForData: (NSMutableDictionary *)list;
 @end
