@@ -1,5 +1,5 @@
 /* 
-   Copyright (C) 2010, 2012 German A. Arias <german@xelalug.org>
+   Copyright (C) 2010, 2012, 2013 German A. Arias
 
    This file is part of FísicaLab application
 
@@ -22,12 +22,7 @@
 
 @implementation FLKinematicsRigidBodies
 
-- (void) crearEcuaciones: (id)sender
-{
-  /* insert your code here */
-}
-
-- (void) setSistema: (id)sender
+- (void) makeEquationsForData: (NSMutableDictionary *)list;
 {
   /* insert your code here */
 }
